@@ -56,7 +56,7 @@ timeout = 5
 socket.setdefaulttimeout(timeout)
 
 color_style = gtk.rc_get_style_by_paths(gtk.settings_get_default() , 'GtkButton', 'osso-logical-colors', gtk.Button)
-fg_colog = color_style.lookup_color('ActiveTextColor')
+fg_color = color_style.lookup_color('ActiveTextColor')
 del color_style
 
 CONFIGDIR="/home/user/.feedingit/"
